@@ -3,11 +3,11 @@ use 5.007;
 use strict;
 use warnings;
 
-use Carp qw(croak);
+use Carp qw(croak confess);
 use POSIX qw(strftime);
 use Time::HiRes qw(time);
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 BEGIN {
 
@@ -36,11 +36,20 @@ BEGIN {
             *$_ = sub {
                 my ($self, $msg) = @_;
 
+                return if $self->level == -1;
+
                 $self->level($ENV{LS_LEVEL}) if defined $ENV{LS_LEVEL};
 
                 if ($sub =~ /^_(\d)$/){
+                    if (defined $self->_log_only){
+                        return if $1 != $self->_log_only;
+                    }
                     return if $1 > $self->level;
                 }
+                if (defined $self->_log_only){
+                    return if $self->_level_value($sub) != $self->_log_only;
+                }
+
                 return if $self->_level_value($sub) > $self->level;
 
                 my $proc = join '|', (caller(0))[1..2];
@@ -101,7 +110,17 @@ sub level {
     $self->{level} = $ENV{LS_LEVEL} if defined $ENV{LS_LEVEL};
     my $lvl;
 
-    if (defined $level) {
+    if (defined $level && $level =~ /^-1$/){
+        $self->{level} = $level;
+    }
+    elsif (defined $level){
+
+        my $log_only;
+
+        if ($level =~ /^=/){
+            $level =~ s/=//;
+            $log_only = 1;
+        }
         if ($level =~ /^\d$/ && defined $levels{$level}){
             $self->{level} = $level;
         }
@@ -112,7 +131,15 @@ sub level {
             CORE::warn
                 "invalid level $level specified, using default 'warning'/4\n";
         }
+
+        if ($log_only){
+            $self->_log_only($self->{level});
+        }
+        else {
+            $self->_log_only(-1);
+        }
     }
+
     return $self->{level};
 }
 sub file {
@@ -247,6 +274,12 @@ sub custom_display {
     }
     return $self->{custom_display};
 }
+sub fatal {
+    my ($self, $msg) = @_;
+
+    $self->display(1);
+    confess("\n" . $self->_0("$msg"));
+}
 sub _level_value {
     my ($self, $level) = @_;
 
@@ -309,6 +342,16 @@ sub _generate_entry {
         print $log_entry;
     }
 }
+sub _log_only {
+    my ($self, $level) = @_;
+    if (defined $level && $level == -1){
+        $self->{log_only} = undef;
+    }
+    else {
+        $self->{log_only} = $level if defined $level;
+    }
+    return $self->{log_only};
+}
 
 1;
 __END__
@@ -337,6 +380,13 @@ Logging::Simple - A simple but flexible logging mechanism.
 
     $log->debug("same as _7(). It'll print now");
 
+    $log->level('=3');
+    $log->_3("with a prepending '=' on level, we'll log this level ONLY");
+
+    $log->fatal("log a message along with confess() output, and terminate");
+
+    $log->level(-1); # disables all levels from doing anything
+
     $log->file('file.log');
     $log->info("this will go to file");
     $log->file(0); # back to STDOUT
@@ -384,6 +434,8 @@ Verbosity levels and associated named equivalents:
 
 =over 4
 
+=item   -1, disables all levels
+
 =item   0, 'emergency|emerg'
 
 =item   1, 'alert'
@@ -407,7 +459,7 @@ have to remember the names at all. Using the numbers is often much easier.
 
 Setting the C<level> will display all messages related to that level and below.
 
-=head1 METHODS
+=head1 INITIALIZATION METHODS
 
 =head2 new(%args)
 
@@ -416,7 +468,7 @@ they can all be set using accessor methods after instantiation. These params
 are:
 
     name        => $str  # optional, default is undef
-    level       => $num  # default 4, options, 0..7
+    level       => $num  # default 4, options, 0..7, -1 to disable all
     file        => $str  # optional, default undef, send in a filename
     write_mode  => $str  # defaults to append, other option is 'write'
     print       => $bool # default on, enable/disable output and return instead
@@ -453,6 +505,11 @@ In hash param mode, send in any or all of the tags with 1 (enable) or 0
 
 You can also send in 1 to enable all of the tags, or 0 to disable them all.
 
+=head2 fatal($msg)
+
+Log the message, along with the trace C<confess()> produces, and die
+immediately.
+
 =head2 custom_display($str|$false)
 
 This will create a custom tag in your output, and place it at the first column
